@echo off
rem *********************************************************************
rem *                                                                   *
rem * NOME SCRIPT: DNSBackup.cmd                                        *
rem *                                                                   *
rem * Script scritto da Alessandro Tani (Sedoc S.r.l.)                  *
rem *                                                                   *
rem * Versione 1.0 - Modificato l'ultima volta il 4/08/2008             *
rem *                da Alessandro Tani                                 *
rem * SCOPO:                                                            *
rem *                                                                   *
rem *  Questo script ha il compito di eseguire il backup di una Zona    *
rem *  DNS integrata in Active Directory                                *
rem *                                                                   *
rem * File di log: %LogDir%\%DataOra%_DNSBackup.log                     *
rem *                                                                   *
rem * PREREQUISITI:                                                     *
rem *                                                                   *
rem *  - Lo script deve essere eseguito con le credenziali di un        *
rem *    utente che fa parte del gruppo globale DNS Admins              *
rem *  - Lo script utilizza il comando %BINPATH%\blat.exe               *
rem *  - Lo script utilizza la variabile d'ambiente %OSLanguage%        *
rem *                                                                   *
rem * TESTO:                                                            *
rem *                                                                   *
rem *  Nessuno                                                          *
rem *                                                                   *
rem * NOTE:                                                             *
rem *                                                                   *
rem *  Nessuna                                                          *
rem *                                                                   *
rem *********************************************************************

rem Definiamo l'ambiente locale
setlocal enableextensions
echo.

rem Impostiamo la variabile d'ambiente che indica dove sono i file eseguibili
set BINPATH=%SystemDrive%\Bin\Exe

rem Controlliamo i parametri inseriti dall'utente
if [%2]	equ [] goto HELP
if [%4] neq [] goto HELP

rem Impostiamo le variabili
set DNSZoneName=%1
set DataDrive=%2
set NAMESERVER=%3
set LOGFILE=%SystemDrive%\Logs\DNSBackup.log
set BodyMsg=%DataDrive%\Backup\Txt\DNSBackup_Messaggio.txt
set Oggetto="Esecuzione salvataggio zona DNS %DNSZoneName%"

rem Impostiamo le variabili per la gestione delle notifiche via email (da modificare di volta in volta)
set ServerSMTP=smtp.homeworks.it
set Email=alessandro.tani@homeworks.it
set From=backupadmin@homeworks.it

rem Intestiamo il file di log
echo ^+-----------------------------------------^+  > %LOGFILE%
echo ^|  FILE DI LOG DEL COMANDO DNSBACKUP.CMD  ^| >> %LOGFILE%
echo ^+-----------------------------------------^+ >> %LOGFILE%
echo. >> %LOGFILE%

rem Controlliamo le variabili d'ambiente
if [%OSLanguage%] equ [] goto NOOSLanguage

rem Controlliamo la presenza dei file e cartelle necessari all'esecuzione
if not exist %SystemDrive%\Logs md %SystemDrive%\Logs
if not exist %BINPATH%\blat.exe goto NOBLAT

rem Calcoliamo la data e l'ora di esecuzione dello script
if /i "%OSLanguage%" equ "EN" for /f "Tokens=1-4 Delims=/ " %%i in ('date /t') do set DATA=%%l%%k%%j-%%i
if /i "%OSLanguage%" equ "EN" for /f "tokens=2-4 delims=/ " %%a in ('date /t') do set OGGDATA=%%a-%%b-%%c
if /i "%OSLanguage%" equ "EN" for /f "tokens=1-4 delims=. " %%a in ('time /t') do set ORA=%%a%%b
if /i "%OSLanguage%" equ "EN" for /f "tokens=1-4 delims=. " %%a in ('time /t') do set OGGORA=%%a:%%b
if /i "%OSLanguage%" equ "IT" for /f "Tokens=1-4 Delims=/ " %%i in ('date /t') do set DATA=%%k%%j%%i
if /i "%OSLanguage%" equ "IT" for /f "Tokens=1-4 Delims=/ " %%i in ('date /t') do set OGGDATA=%%k-%%j-%%i
if /i "%OSLanguage%" equ "IT" for /f "Tokens=1-2 Delims=. " %%i in ('time /t') do set ORA=-%%i%%j
if /i "%OSLanguage%" equ "IT" for /f "Tokens=1-2 Delims=. " %%i in ('time /t') do set OGGORA=%%i:%%j
set ORA=%ORA::=-%
set DATAeORA=%DATA%%ORA%

rem Controlliamo che le cartelle che utilizza lo script esistano
if not exist %DataDrive%\Backup (
	echo Creaiamo la cartella %DataDrive%\Backup >> %LOGFILE%
	md %DataDrive%\Backup >> %LOGFILE%
	echo. >> %LOGFILE%
)
if not exist %DataDrive%\Backup\Files (
	echo Creaiamo la cartella %DataDrive%\Backup\Files >> %LOGFILE%
	md %DataDrive%\Backup\Files >> %LOGFILE%
	echo. >> %LOGFILE%
)

if not exist %DataDrive%\Backup\Txt (
	echo Creaiamo la cartella %DataDrive%\Backup\Txt >> %LOGFILE%
	md %DataDrive%\Backup\Txt >> %LOGFILE%
	echo. >> %LOGFILE%
)

rem Cancelliamo eventuali file di backup delle zone DNS precedenti
echo Cancelliamo eventuali file di backup delle zone DNS precedenti >> %LOGFILE%
echo. >> %LOGFILE%
if exist %DataDrive%\Backup\Files\%DNSZoneName%.backup.txt del /f /q %DataDrive%\Backup\Files >> %LOGFILE%


rem Eseguiamo il backup della Zona DNS integrata con Active Directory
echo Backup della zona DNS %DNSZoneName% eseguito il giorno %OGGDATA% alle %OGGORA% >> %LOGFILE%
echo Backup della zona DNS %DNSZoneName% eseguito il giorno %OGGDATA% alle %OGGORA%
echo. >> %LOGFILE%
if [%NAMESERVER%] equ [] (
	DnsCmd /ZoneExport %DNSZoneName% %DNSZoneName%.backup.txt >> %LOGFILE%
	echo. >> %LOGFILE%
	echo In allegato a questo messaggio e' riportato il file di log del salvataggio della zona %DNSZoneName% che si trova sul server %COMPUTERNAME% del %OGGDATA% alle %OGGORA% > %BodyMsg%
	echo Spostiamo il file %windir%\System32\dns\%DNSZoneName%.backup.txt nella cartella %DataDrive%\Backup\Files >> %LOGFILE% 
	move /y %windir%\System32\dns\%DNSZoneName%.backup.txt %DataDrive%\Backup\Files >> %LOGFILE%
) else (
	DnsCmd %NAMESERVER% /ZoneExport %DNSZoneName% %DNSZoneName%.backup.txt >> %LOGFILE%
	echo. >> %LOGFILE%
	echo In allegato a questo messaggio e' riportato il file di log del salvataggio della zona %DNSZoneName% che si trova sul server %NAMESERVER% del %OGGDATA% alle %OGGORA% > %BodyMsg%
	echo. >> %BodyMsg%
	echo Per eseguire di nuovo il salvataggio della zona DNS sul server %NAMESERVER%, ricordarsi di cancellare il file %windir%\System32\dns\%DNSZoneName%.backup.txt che si trova sul server %NAMESERVER% >> %BodyMsg%
	echo Per eseguire di nuovo il salvataggio della zona DNS sul server %NAMESERVER%, >> %LOGFILE%
	echo ricordarsi di cancellare il file %windir%\System32\dns\%DNSZoneName%.backup.txt >> %LOGFILE%
	echo che si trova sul server %NAMESERVER% >> %LOGFILE%
)

rem Inviamo un messaggio di email
echo. >> %LOGFILE%
echo Inviamo il messaggio di email contente il file di log relativo al job di backup >> %LOGFILE%
if [%ServerSMTP%] equ [] (
	echo Non  stato impostato il server SMTP con cui inviare le email >> %LOGFILE%
	echo. >> %LOGFILE%
	echo Fine del file di log >> %LOGFILE%
) else (
	echo %BINPATH%\blat.exe %BodyMsg% -attach %LOGFILE% -subject %Oggetto% -to %Email% -f %From% -server %ServerSMTP% -q >> %LOGFILE%
	echo. >> %LOGFILE%
	echo Fine del file di log >> %LOGFILE%
	%BINPATH%\blat %BodyMsg% -attach %LOGFILE% -subject %Oggetto% -to %Email% -f %From% -server %ServerSMTP% -q
	)
goto END

:NOBLAT
echo Non  stato possibile trovare il file %BINPATH%\blat.exe    >> %LOGFILE%
echo pertanto lo script non pu essere eseguito.                 >> %LOGFILE%
echo Controllare che il percorso del file Blat.exe sia corretto. >> %LOGFILE%
goto END

:NOOSLanguage
echo La variabile d'ambiente "OSLanguage" non e' stata impostata >> %LOGFILE%
echo per far girare questo script e' necessario impostare questa >> %LOGFILE%
echo variabile. Questa variabile deve essere impostata ad IT se  >> %LOGFILE%
echo il sistema operativo e' in Italiano ed ad EN se il sistema  >> %LOGFILE%
echo operativo e' in Inglese.                                    >> %LOGFILE%

:HELP
echo Questo script ha il compito di eseguire il backup di una Zona DNS
echo integrata in Active Directory.
echo.
echo Prerequisiti:
echo.
echo  - lo script deve venire eseguito da un utente che fa parte del
echo    gruppo di dominio denominato "DNS Admins"
echo  - Lo script utilizza il comando %BINPATH%\blat.exe
echo  - Lo script utilizza la variabile d'ambiente %OSLanguage%
echo.
echo Sintassi:
echo.
echo   dnsbackup ^<Nome_Zona_DNS_Da_Salvare^> ^<Disco_Backup^> [Nome_DNS_Server]
echo.
echo Dove:
echo.
echo   - ^<Nome_Zona_DNS_Da_Salvare^>: indica il nome della zna DNS da salvare,
echo                                 ad esempio: homeworks.it
echo.
echo   - ^<Disco_Backup^>: su quale disco eseguire il salvataggio della zona DNS
echo.
echo   - [Nome_DNS_Server]: questo campo e' opzionale e sta ad indicare su quale
echo                        server DNS si trova la zona da salvare. Se lo script
echo                        viene eseguito direttamente sul server DNS che ospita
echo                        la zona da salvare, questa voce puo' venire omessa.
echo.
echo Esempi:
echo.
echo   dnsbackup homeworks.it E:
echo   dnsbackup homeworks.it E: ns2.homeworks.it

:END
echo.
endlocal
exit /b


